@@ -49,28 +49,24 @@ regExMap['de_DE']['person'] = /Name des Gastes +(.*) Name des Gastes bearbeiten/
 regExMap['de_DE']['dateFormat'] = "dddd, d. MMMM yyyy hh:mm";
 
 function main(text) {
-    var res = JsonLd.newObject("LodgingReservation");
+    var res = JsonLd.newLodgingReservation();
 
     for (var locale in regExMap) {
         var bookingRef = text.match(regExMap[locale]['bookingRef']);
         // If no booking reference go to the next locale
         if (!bookingRef)
             continue;
-
         res.reservationNumber = bookingRef[1];
 
         var hotelName = text.match(regExMap[locale]['hotelName']);
         if (!hotelName)
             return null;
-
-        res.reservationFor = JsonLd.newObject("LodgingBusiness");
         res.reservationFor.name = hotelName[1];
 
         var hotel = text.match(regExMap[locale]['hotelInformation']);
         if (!hotel)
             return null;
 
-        res.reservationFor.address = JsonLd.newObject("PostalAddress");
         res.reservationFor.address.streetAddress = hotel[1];
         res.reservationFor.address.postalCode = hotel[3];
         res.reservationFor.address.addressLocality = hotel[2];
@@ -93,14 +89,40 @@ function main(text) {
         res.checkoutTime = JsonLd.toDateTime(departureDate[1] + " " + departureDate[2], regExMap[locale]['dateFormat'], locale);
         idx += departureDate.index + departureDate[0].length;
 
-
-        res.underName = JsonLd.newObject("Person");
         var name = text.substr(idx).match(regExMap[locale]['person']);
         if (!name)
             return null;
         res.underName.name = name[1];
 
-
         return res;
     }
 }
+
+function parseHtml(doc)
+{
+    var res = JsonLd.newLodgingReservation();
+    var elem = doc.eval("//table[@class=\"mg_conf_hotel_preview\"]")[0];
+    res.reservationFor.name = elem.eval("(.//b|.//strong)")[0].content;
+
+    var fullAddr = elem.eval(".//tr")[1].recursiveContent;
+    var addr = fullAddr.match(/^(.*), (.*?), (.*?), ([^,]*?)\s*-?\s*$/);
+    res.reservationFor.address.streetAddress = addr[1];
+    res.reservationFor.address.addressLocality = addr[2];
+    res.reservationFor.address.postalCode = addr[3];
+    res.reservationFor.address.addressCountry = addr[4];
+
+    res.reservationFor.telephone = elem.eval(".//*[@class=\"u-phone\"]")[0].content;
+
+    // reservation id is the prefix in the mailto link, unlike other occurences this seems most reliably present
+    var email = elem.eval(".//tr/td/a")[1].attribute("href").match(/mailto:(\d+)-/);
+    if (email) {
+        res.reservationNumber = email[1]
+    }
+
+    elem = doc.eval("//table[@class=\"mg_conf_booking_summary\"]")[0];
+    var times = elem.eval(".//time");
+    res.checkinTime = times[0].attribute("datetime");
+    res.checkoutTime = times[1].attribute("datetime");
+
+    return res;
+}
