@@ -76,6 +76,8 @@ void GenericUic918Extractor::extract(const QByteArray &data, QJsonArray &result,
                     trip.insert(QStringLiteral("departureTime"), rct2.outboundDepartureTime().toString(Qt::ISODate));
                     trip.insert(QStringLiteral("arrivalTime"), rct2.outboundArrivalTime().toString(Qt::ISODate));
                 }
+
+                seat.insert(QStringLiteral("seatingType"), rct2.outboundClass());
                 break;
             }
             default:
@@ -88,11 +90,18 @@ void GenericUic918Extractor::extract(const QByteArray &data, QJsonArray &result,
     ticket.insert(QStringLiteral("ticketToken"), QString(QLatin1String("aztecbin:") + QString::fromLatin1(data.toBase64())));
     ticket.insert(QStringLiteral("ticketedSeat"), seat);
 
+    QJsonObject person;
+    person.insert(QStringLiteral("@type"), QLatin1String("Person"));
+    if (!rct2.passengerName().isEmpty()) {
+        person.insert(QStringLiteral("name"), rct2.passengerName());
+    }
+
     QJsonObject res;
     res.insert(QStringLiteral("@type"), QLatin1String("TrainReservation"));
     res.insert(QStringLiteral("reservationFor"), trip);
     res.insert(QStringLiteral("reservationNumber"), p.pnr());
     res.insert(QStringLiteral("reservedTicket"), ticket);
+    res.insert(QStringLiteral("underName"), person);
 
     result.push_back(res);
 }
