@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KITINERARY_SORTUTIL_H
@@ -32,7 +32,7 @@ namespace SortUtil
     KITINERARY_EXPORT QDateTime startDateTime(const QVariant &res);
 
     /** Returns the (end) time associated with the given reservation. */
-    KITINERARY_EXPORT QDateTime endtDateTime(const QVariant &res);
+    KITINERARY_EXPORT QDateTime endDateTime(const QVariant &res);
 
     /** Sorting function for top-level reservation/visit/event elements. */
     KITINERARY_EXPORT bool isBefore(const QVariant &lhs, const QVariant &rhs);
