@@ -17,7 +17,7 @@
    02110-1301, USA.
 */
 
-#include "structureddataextractor.h"
+#include "structureddataextractor_p.h"
 #include "htmldocument.h"
 #include "logging.h"
 
@@ -55,28 +55,27 @@ static void parseJson(const QByteArray &data, QJsonArray &result)
         }
     }
     if (jsonDoc.isArray()) {
-        for (const auto &v : jsonDoc.array()) {
-            result.push_back(v);
-        }
+        const auto jsonArray = jsonDoc.array();
+        std::copy(jsonArray.begin(), jsonArray.end(), std::back_inserter(result));
     } else if (jsonDoc.isObject()) {
         result.push_back(jsonDoc.object());
     }
 }
 
-static QString valueForItemProperty(HtmlElement elem)
+static QString valueForItemProperty(const HtmlElement &elem)
 {
     // TODO see https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/itemprop#Values
     const auto elemName = elem.name();
     QString v;
     if (elemName == QLatin1String("meta")) {
-        v = elem.attribute(QLatin1String("content"));
+        v = elem.attribute(QStringLiteral("content"));
     } else if (elemName == QLatin1String("time")) {
-        v = elem.attribute(QLatin1String("datetime"));
+        v = elem.attribute(QStringLiteral("datetime"));
     } else if (elemName == QLatin1String("link") || elemName == QLatin1String("a")) {
-        if (elem.hasAttribute(QLatin1String("href"))) {
-            v = elem.attribute(QLatin1String("href"));
-        } else if (elem.hasAttribute(QLatin1String("content"))) {
-            v = elem.attribute(QLatin1String("content"));
+        if (elem.hasAttribute(QStringLiteral("href"))) {
+            v = elem.attribute(QStringLiteral("href"));
+        } else if (elem.hasAttribute(QStringLiteral("content"))) {
+            v = elem.attribute(QStringLiteral("content"));
         } else {
             v = elem.recursiveContent();
         }
@@ -87,12 +86,12 @@ static QString valueForItemProperty(HtmlElement elem)
     return v;
 }
 
-static void parseMicroData(HtmlElement elem, QJsonObject &obj)
+static void parseMicroData(const HtmlElement &elem, QJsonObject &obj)
 {
     auto child = elem.firstChild();
     while (!child.isNull()) {
-        const auto prop = child.attribute(QLatin1String("itemprop"));
-        const auto type = child.attribute(QLatin1String("itemtype"));
+        const auto prop = child.attribute(QStringLiteral("itemprop"));
+        const auto type = child.attribute(QStringLiteral("itemtype"));
         if (type.startsWith(QLatin1String("http://schema.org/"))) {
             QJsonObject subObj;
             parseMicroData(child, subObj);
@@ -109,16 +108,16 @@ static void parseMicroData(HtmlElement elem, QJsonObject &obj)
     }
 }
 
-static void extractRecursive(HtmlElement elem, QJsonArray &result)
+static void extractRecursive(const HtmlElement &elem, QJsonArray &result)
 {
     // JSON-LD
-    if (elem.name() == QLatin1String("script") && elem.attribute(QLatin1String("type")) == QLatin1String("application/ld+json")) {
+    if (elem.name() == QLatin1String("script") && elem.attribute(QStringLiteral("type")) == QLatin1String("application/ld+json")) {
         parseJson(elem.content().toUtf8(), result);
         return;
     }
 
     // Microdata
-    const auto itemType = elem.attribute(QLatin1String("itemtype"));
+    const auto itemType = elem.attribute(QStringLiteral("itemtype"));
     if (itemType.startsWith(QLatin1String("http://schema.org/"))) {
         QJsonObject obj;
         parseMicroData(elem, obj);
@@ -129,7 +128,7 @@ static void extractRecursive(HtmlElement elem, QJsonArray &result)
         const QUrl typeUrl(itemType);
         obj.insert(QStringLiteral("@type"), typeUrl.fileName());
 
-        const auto itemProp = elem.attribute(QLatin1String("itemprop"));
+        const auto itemProp = elem.attribute(QStringLiteral("itemprop"));
         if (!itemProp.isEmpty() && !result.isEmpty()) {
             // this is likely a child of our preceding sibling, but broken XML put it here
             auto parent = result.last().toObject();
